(*^

::[paletteColors = 128; 
	fontset = title, "Times-Bold", 24, L2, center, bold, nohscroll;
	fontset = subtitle, "Times-Bold", 18, L2, center, bold, nohscroll;
	fontset = subsubtitle, "Times-Bold", 14, L2, center, bold, nohscroll;
	fontset = section, "Times-Bold", 18, L2, bold, nohscroll, grayBox;
	fontset = subsection, "Times-Bold", 14, L2, bold, nohscroll, blackBox;
	fontset = subsubsection, "Times-Bold", 12, L2, bold, nohscroll, whiteBox;
	fontset = text, "Times-Roman", 16, L2, nohscroll;
	fontset = smalltext, "Times-Roman", 10, L2, nohscroll;
	fontset = input, "Courier-Bold", 12, L2, bold, nowordwrap;
	fontset = output, "Courier", 12, L2, nowordwrap;
	fontset = message, "Courier", 12, L2, R21845, G21845, B21845, nowordwrap;
	fontset = print, "Courier", 12, L2, nowordwrap;
	fontset = info, "Courier", 12, L2, nowordwrap;
	fontset = postscript, "Courier", 12, L2, nowordwrap;
	fontset = name, "Times-Italic", 11, L2, italic, R21845, G21845, B21845, nowordwrap, nohscroll;
	fontset = header, "Times", 10, L2;
	fontset = footer, "Times", 12, L2, center;
	fontset = help, "Times-Roman", 14, L2, nohscroll;
	fontset = clipboard, "New York", 12, L2;
	fontset = completions, "Courier", 16, L2, nowordwrap;
	fontset = network, "Courier", 10, L2, nowordwrap;
	fontset = graphlabel, "Courier", 12, L2, nowordwrap;
	fontset = special1, "New York", 12, L2, nowordwrap;
	fontset = special2, "New York", 12, L2, center, nowordwrap;
	fontset = special3, "New York", 12, L2, right, nowordwrap;
	fontset = special4, "New York", 12, L2, nowordwrap;
	fontset = special5, "New York", 12, L2, nowordwrap;]
:[font = title; inactive; ]
Applications of Linear First Order Differential Equations

:[font = section; inactive; ]
Newton's Law of Cooling:
:[font = smalltext; inactive; ]
BRUTUS                      Thou hast described
   	A hot friend cooling. 
   	[Shakespeare, Julius Caesar, Act 4, Scene 2]  
   	(with apologies for the macabre tone of the example!)
   	
:[font = text; inactive; ]
   	
   	Newton's Law of Cooling says that the rate of change of an object's temperature is proportional to the difference of the surrounding medium's temperature  and the temperature of the object.  The constant of proportionality is a material property of the object. For instance, metal objects lose or gain temperature rapidly so the proportionality constant is quite high, while insulated objects have been treated to reduce the constant of proportionality.  In terms of differential equations, Newton's Law says
	dT
	--  = -k(T- A)
	dt            
where T(t) is the temperature of the object, and A
is the surrounding medium (like Air) temperature.  Take k > 0 and then the negative sign adjusts for the direction of the change of temperature.  If the object temperature is higher than the surrounding medium temperature, the object temperature decreases.  Conversely, if the surrounding medium temperature is higher, the object's temperature is increasing as time passes.
:[font = text; inactive; ]
Suppose that the temperature of the surrrounding medium is changing:
	A(t) = -t/2.
Then after a little rearrangement, we wiil have a linear first order non-homogeneous differential equation for the temperature of the object.
	T'(t) + kT = k A(t)
which we can proceed to solve.
We are going to apply Newton's Law of Cooling to the situation described in the mystery story to determine the time of death.  In the story problem, the air temperature is falling steadily from 0 at the starting time of 8:00AM, so that
	A(t) = -t/2.
We will assume for simplicity that the coefficient of cooling is a constant  k, although for a complicated object such as a corpse, this is probably  an oversimplification.  Note that we do not have the value of the constant k, this will have to be determined.
:[font = text; inactive; ]
Because of the way Mathematica works, it is easiest to apply the formula for the solution of a first-order linear differential equation, rather than go through the derivation of the solution, as we have done in class.  First make the definition of the integrating factor:  

:[font = text; inactive; ]
(The defintion in terms of Mathematica is somewhat sophisticated in concept, seee Sections 2.1.12 and  4.1.4 for a discusssion of the ideas.)
:[font = input; ]
mu = Function[{a,t}, Exp[Integrate[a,t]]]
:[font = text; inactive; ]
Now in terms of this integrating factor, write down the solution formula for the general first order linear non-homogeneous differential equation:
:[font = input; ]
FOLDESoln = Function[{a,b,t}, Simplify[(Integrate[mu[a,t]*b, t] + c)/mu[a,t]] ]
:[font = text; inactive; ]
This "solution operator" is applied in the following way:  The first variable is the coefficient function a[t], the second variable is the non-homogeneous term b[t] on the right side of the equation, and the third variable is the independent variable of the equaation, usually t or x.
:[font = text; inactive; ]
Now we can apply this to the differential equation for the cooling "body" for which the differential equation of Newton's Law of cooling is
dT                  k t
---- + kT =   - ---
 dt                    2
:[font = input; ]
soln = FOLDESoln[ k, -k*t/2, t]
:[font = text; inactive; ]
Now we know that that body temperature at time 0 is 25 C (this is the initial conditionof the problem.) This will allow us to determine the arbitrary constant c in the solution.
:[font = input; ]
Solve [( soln /. t -> 0) == 25, c]
:[font = text; inactive; ]
Inserting this value in for the constant will give us the temperature as a function of time in terms of the parameter  k.
:[font = input; ]
temp = soln /. c -> -(1- 50*k)/(2*k)
:[font = text; inactive; ]
Just to illustrate, different values of k give different graphs of temperature versus time.  A larger value of k should give greater temperature decline in the same amount of time.  So take, say k = 1 and plot temperature as function of time:
:[font = input; ]
Plot[ (temp /. k -> 1), {t, 0,2}]
:[font = text; inactive; ]
Notice that at time t = 1, the temperature would be about 10 C for this value of k.  Now look at the plot of temperature versus time for k = 0.1
:[font = input; ]
Plot[ (temp /. k -> 0.1), {t, 0,2}]
:[font = text; ]
Notice that at time t = 1, the temperature in this case is about 23 C.  So we expect the value of k to be between 0.1 and 1.0.  Now we  actually  need to determine the constant k.  For this we use the second observation of temperture at time t = 1.  Then we solve the resulting equation for k.

:[font = input; ]
FindRoot[ (temp /. t -> 1) == 20, {k, 0.1}]
:[font = input; ]
temp = temp /. %
:[font = input; ]
Plot[temp, {t, -2, 2}]
:[font = text; inactive; ]
Notice that the temperture has been declining, and that the temperature was 25 C at t= 0, (8:00 AM) and was 20 C at t = 1 (9:00 AM).  At about 2 hours previous the temperature was  37 C.  So solve for the exact time of death!
:[font = input; ]
FindRoot[ temp == 37, {t, -2}]
:[font = input; ]
60*(-1.80241)
:[font = text; inactive; ]
So death occurred at 1 hour, 48 minutes previously at 6:12 AM.

^*)