(*^

::[paletteColors = 128; 
	fontset = title, "Times-Bold", 24, L2, center, bold, nohscroll;
	fontset = subtitle, "Times-Bold", 18, L2, center, bold, nohscroll;
	fontset = subsubtitle, "Times-Bold", 14, L2, center, bold, nohscroll;
	fontset = section, "Times-Bold", 18, L2, bold, nohscroll, grayBox;
	fontset = subsection, "Times-Bold", 14, L2, bold, nohscroll, blackBox;
	fontset = subsubsection, "Times-Bold", 12, L2, bold, nohscroll, whiteBox;
	fontset = text, "Times-Roman", 12, L2, nohscroll;
	fontset = smalltext, "Times-Roman", 10, L2, nohscroll;
	fontset = input, "Courier-Bold", 12, L2, bold, nowordwrap;
	fontset = output, "Courier", 12, L2, nowordwrap;
	fontset = message, "Courier", 12, L2, R21845, G21845, B21845, nowordwrap;
	fontset = print, "Courier", 12, L2, nowordwrap;
	fontset = info, "Courier", 12, L2, nowordwrap;
	fontset = postscript, "Courier", 12, L2, nowordwrap;
	fontset = name, "Times-Italic", 11, L2, italic, R21845, G21845, B21845, nowordwrap, nohscroll;
	fontset = header, "Times", 10, L2;
	fontset = footer, "Times", 12, L2, center;
	fontset = help, "Times-Roman", 14, L2, nohscroll;
	fontset = clipboard, "New York", 12, L2;
	fontset = completions, "Courier", 16, L2, nowordwrap;
	fontset = network, "Courier", 10, L2, nowordwrap;
	fontset = graphlabel, "Courier", 12, L2, nowordwrap;
	fontset = special1, "New York", 12, L2, nowordwrap;
	fontset = special2, "New York", 12, L2, center, nowordwrap;
	fontset = special3, "New York", 12, L2, right, nowordwrap;
	fontset = special4, "New York", 12, L2, nowordwrap;
	fontset = special5, "New York", 12, L2, nowordwrap;]
:[font = smalltext; inactive; ]


THOMAS DEKKER 1570?1641?
Dost thou laugh to see how fools are vexed
To add to golden numbers, golden numbers?
Patient Grissil, Act I
:[font = title; inactive; ]
Examples of Numerical Methods for 
First Order Initial Value Problems

:[font = subsection; inactive; ]
We  need to access the programs for the numerical methods since these programs are not built into Mathematica as pre-loaded programs.  The following commands will do this necessary task.
:[font = input; ]
<</Users/Mathfac/dunbar/Euler.m
:[font = input; ]
<</Users/Mathfac/dunbar/ModEuler.m
:[font = input; ]
<</Users/Mathfac/dunbar/RKsimple.m
:[font = input; ]
<<NumericalMath/RungeKutta.m
:[font = text; inactive; ]
The Mathematica notation <<.....    tells Mathematica to load a text file containing a program of further Mathemtica commands.

Mathematica searches a set  of standard places to find programs when asked to load a program.  The  set of locations is kept in the Path environment variable (just as in the UNIX operating system for those who know the lingo) which is
:[font = input; ]
$Path
:[font = text; inactive; ]
Since some of the programs are simple minded example programs that I wrote, I keep them in my directory, rather than the system locations.  Since my directory is not in the standard set of locations for Mathematica, I need to specify the full  location to retrieve them.  The RungeKutta package is a (near) industrial grade program, so it is included in the standard set of locations.
:[font = input; ]
mu = Function[{a,t}, Exp[Integrate[a,t]]]
:[font = input; ]
FOLDESoln = Function[{a,b,t}, Simplify[(Integrate[mu[a,t]*b, t] + c)/mu[a,t]] ]
:[font = subsection; inactive; ]
With these I can solve simple first order linear differential equations without trouble so that I have the exact solution available for comparison.  For instance solve,

y' = 4 x - 2y,     y(0) = 2

:[font = input; ]
genlsoln = FOLDESoln[2,4 x, x]
:[font = input; ]
genlsoln /. x -> 0
:[font = subsection; inactive; ]
So the constant c = 3, just by inspection.   The exact solution to the initial value problem is
:[font = input; ]
exactsoln = genlsoln /. c -> 3
:[font = subsection; inactive; ]
Now we will solve this eequation numerically and compare the soln to the exact solution.
:[font = input; ]
?Euler
:[font = input; ]
eulersoln = Euler[{1, 4 x - 2 y}, {x,y}, {0,2}, {5, 0.1}]
:[font = input; ]
modeulersoln = ModEuler[{1, 4 x - 2 y}, {x,y}, {0,2}, {5,0.1}]
:[font = input; ]
rksimple = RKsimple[{1, 4 x - 2 y}, {x,y}, {0,2}, {5, 0.1}]
:[font = input; startGroup; ]
?RungeKutta
:[font = info; inactive; endGroup; ]
RungeKutta[ListofODEexpressions, ListOfVariables, ListOfInitialValues,  Finalx,
   ErrorTolerance, (OptionalParameters...)] integrates system of ODEs by an embedded
   explicit Runge-Kutta method of order 4-5. E.g., to solve
 
	y' == y - yz
 	z' == -z + yz
 
	RungeKutta[ {y - y z, -z + y z}, {x,y,z}, {0,.5,.5}, 1, 10^-5,
 		InitialStepSize->0.1, ProgressTrace->True ]
 
ListOfVariables contains the independent variable followed by dependent variables in the
   same order as the ODEs. Initial values are specified in the same order. The solution can
   be plotted by invoking the function `PlotODESolution' for any given component, i.e., x
   vs y, x vs z. Do ?PlotODESolution for details.
:[font = input; ]
RK = RungeKutta[ {4 x - 2 y}, {x,y}, {0,2}, 5, 10^-5, InitialStepSize -> 0.1]
:[font = subsection; inactive; ]
Look at the number of points in the Euler solution and compare it to the number of points in the Runge - Kutta solution.  
:[font = input; ]
Dimensions[eulersoln]
:[font = input; ]
Dimensions[RK]
:[font = subsection; inactive; ]
This occurs because the Runge Kutta Fehlberg method is adaptive, that is, it takees large steps when possible, small steps when necessary.

:[font = input; ]
eulerplot = ListPlot[eulersoln, PlotJoined -> True, PlotStyle -> {GrayLevel[0.5]},  DisplayFunction -> Identity]
:[font = input; ]
modeulerplot = ListPlot[modeulersoln,PlotJoined -> True, PlotStyle -> {GrayLevel[0.7]},  DisplayFunction -> Identity]
:[font = input; ]
rksimpleplot = ListPlot[rksimple,PlotJoined -> True,  PlotStyle -> {GrayLevel[0.9]},  DisplayFunction -> Identity]
:[font = input; ]
RKplot = ListPlot[RK, PlotJoined-> True, DisplayFunction -> Identity]
:[font = subsection; inactive; ]
Now display all of these plots similtaneously with the more accurate succcessively drawn with less dashing, and more filled in.
:[font = input; ]
Show[eulerplot, modeulerplot, rksimpleplot, RKplot, DisplayFunction -> $DisplayFunction, PlotRange -> {{0,2}, {1,2}}]
:[font = subsection; inactive; ]
Notice thatfor all practical purposes, you can't distinguish the true solution from the numerical solution by a simple Runge Kutta, the RKF45 algorithm or even the modified Euler method.!!   Notice the large steps taken by the RKF45 algorithm giving the broken line appearance.
:[font = section; inactive; ]
Now try numerically solving and plotting the equation solved in the last project:

:[font = input; ]
<<RKsimple.m

:[font = input; ]
ModEuler[{1, (1/8)*(70- 20*Cos[Pi*t/12] - T) + 2}, {t,T}, {0,72}, {48, 0.25}];
:[font = input; ]
ListPlot[%, PlotJoined -> True]
:[font = subsection; inactive; ]
Now try the equation from the class notes which did not have a solution in terms of elementary function.
:[font = input; ]
ModEuler[{1, 1 - x - y + x*y^2}, {x,y}, {0,0}, {5, 0.1}];
:[font = input; ]
ListPlot[%, PlotJoined -> True]
^*)