(*^

::[paletteColors = 128; 
	fontset = title, "Times-Bold", 24, L2, center, bold, nohscroll;
	fontset = subtitle, "Times-Bold", 18, L2, center, bold, nohscroll;
	fontset = subsubtitle, "Times-Bold", 14, L2, center, bold, nohscroll;
	fontset = section, "Times-Bold", 18, L2, bold, nohscroll, grayBox;
	fontset = subsection, "Times-Bold", 14, L2, bold, nohscroll, blackBox;
	fontset = subsubsection, "Times-Bold", 12, L2, bold, nohscroll, whiteBox;
	fontset = text, "Times-Roman", 18, L2, nohscroll;
	fontset = smalltext, "Times-Roman", 10, L2, nohscroll;
	fontset = input, "Courier-Bold", 12, L2, bold, nowordwrap;
	fontset = output, "Courier", 12, L2, nowordwrap;
	fontset = message, "Courier", 12, L2, R21845, G21845, B21845, nowordwrap;
	fontset = print, "Courier", 12, L2, nowordwrap;
	fontset = info, "Courier", 12, L2, nowordwrap;
	fontset = postscript, "Courier", 12, L2, nowordwrap;
	fontset = name, "Times-Italic", 11, L2, italic, R21845, G21845, B21845, nowordwrap, nohscroll;
	fontset = header, "Times", 10, L2;
	fontset = footer, "Times", 12, L2, center;
	fontset = help, "Times-Roman", 14, L2, nohscroll;
	fontset = clipboard, "New York", 12, L2;
	fontset = completions, "Courier", 16, L2, nowordwrap;
	fontset = network, "Courier", 10, L2, nowordwrap;
	fontset = graphlabel, "Courier", 12, L2, nowordwrap;
	fontset = special1, "New York", 12, L2, nowordwrap;
	fontset = special2, "New York", 12, L2, center, nowordwrap;
	fontset = special3, "New York", 12, L2, right, nowordwrap;
	fontset = special4, "New York", 12, L2, nowordwrap;
	fontset = special5, "New York", 12, L2, nowordwrap;]
:[font = title; inactive; ]
Orthogonal Trajectories
:[font = smalltext; inactive; ]

PETRUCCIO

      	Evermore crossed and crossed, nothing but crossed.	 10
      	
      	The Taming of the Shrew, Act 4, Scene 6
      	(badly out of context, but the most relevant I could find!)
:[font = text; inactive; ]
The problem of finding orthogonal trajectories of a given family of curves arises in many physical situations .  (The term "orthogonal trajectories" will be defined shortly, so hang in there!)  For example, in a two-dimensional electric field, the lines of force and the lines of equal electrical potential are orthogonal trajectories of each other.

Let's see what this really means.  From a well-known physics text (The Feynmann Lectures on Physics, by Nobel prize-winner Richard Feynmann) I extracted the following fact:  The lines of electric force (the lines along which an electron would be pulled) near a pair of equal point charges will be the level curves of the family x^2 - y^2 == c.  Examine the family of level curves given implicitly by this expression.
:[font = input; ]
ContourPlot[ x^2 - y^2, {x, -1, 1}, {y, -1, 1}]
:[font = text; inactive; ]
Now the equippotential lines are the lines along which an electron would feel the same potential energy due to the presence of the two fixed equal charges.  From the physics text, the equipotential lines are the family of level curves of the function f(x, y) = 2 x y.  Examine the level curves.
:[font = input; ]
ContourPlot[ 2 x y, {x, -1, 1}, {y, -1, 1}]
:[font = text; inactive; ]
If  you examine both plots simultaneously, it appears that the curves are mutually perpendicular at all points.  Take a look at two of these curves simultaneously, say the member of each family corresponding to the value c = 1.
:[font = smalltext; inactive; ]
Because of the  way Mathematica works, I found it easiest to convert each of these to a parametric  curve to display them simultaneously.  For  x^2 - y^2 = c, I used some knowledge from  calculus to express the curve parametrically as ( Cosh[t], Sinh[t]).   The other curves are  much more easily seen to be given parameetrically as (t,  1/2t) using standard tricks from calculus.

:[font = input; ]
ParametricPlot[ {{Cosh[t], Sinh[t]}, {t, 1/(2 t)}}, {t, -2, 2}, 
AspectRatio -> Automatic, PlotRange -> {{0,2}, {0,2}} ]
:[font = text; inactive; ]
Notice that here it is clear that the curves intersct at a right angle.  More precisely, the tangent lines to the curves meeet in a right angle.  Since the curves are given  implicitly, we can implicitly differentiate the expression to express the slopes of the tangent lines.
:[font = input; ]
SetAttributes[ c, Constant]
:[font = smalltext; inactive; ]
See Mathematica ,      page 413
:[font = input; ]
D[ x^2 - y[x]^2  == c, x]
:[font = text; inactive; ]
This is the standard implicit differentiation.  Now we will extract the derivative as a function of the x and y values.  Note the use of the Reduce command, rather than Solve.  Reduce[...] essentially re-expresses the equation, rather than returning a solution rule.  This is more in keeping with what we want.
:[font = input; ]
Reduce[%, y'[x]]
:[font = text; inactive; ]
Notice that Mathematica is an extremely conscientious student, preserving, all of the conditions under which solutions are permitted.  Most of us "reduce" an equation rather callously, implicitly ignoring all of these conditions.  We only need the  "usual" solution, so we will extract it bit by bit from this long expression.
:[font = input; ]
First[%]
:[font = input; ]
DE1 = Last[%]
:[font = text; inactive; ]
Here is the differential equation satisfied by the first family of force field lines.  Now we will do the same with the seconfd family of  equipotential lines.
:[font = input; ]
D[ 2 x y[x] == c, x]
:[font = input; ]
Reduce[%, y'[x]]
:[font = input; ]
DE2 = Last[ First[%]]
:[font = text; inactive; ]
Now let's take a look at how these slopes are related.  
:[font = input; ]
Last[DE1] Last[DE2]

:[font = text; inactive; ]
The product of the slopes is -1, just as it should be.  Perpendicular lines have slopes which are negative reciprocals of each other.
:[font = text; inactive; ]
Let's look at another more complicated example.  The following gives the forcce filed lines near the edge of a charged plate.
:[font = input; ]
ContourPlot[ Sqrt[ (Sqrt[x^2 + y^2] + x)/2], {x,-1,1}, {y,-1,1}]
:[font = text; inactive; ]
The following will give the lines of equal potential near the edge of the plate.
:[font = input; ]
ContourPlot[ Sqrt[ (Sqrt[x^2 + y^2] - x)/2], {x,-1,1}, 
:[font = text; inactive; ]
Let's derive (literally!) the differential equation for the first set of  force field lines.
:[font = input; ]
D[Sqrt[ (Sqrt[x^2 + y[x]^2] + x)/2],x]
:[font = input; ]
Reduce[%, y'[x]]
:[font = input; ]
DE3 = Last[ First[%]]
:[font = text; inactive; ]
Now let's derive the differential equation for the equipotential lines.
:[font = input; ]
D[Sqrt[ (Sqrt[x^2 + y[x]^2] - x)/2] == c,x]
:[font = input; ]
DE4 = Last[First[Reduce[%, y'[x]]]]
:[font = text; inactive; ]

Finally, let's take the right sides of these differential equations, and check to see if they are negative reciprocals of each other.
:[font = input; ]
Expand[Last[DE4] Last[DE3]]
:[font = input; ]
Simplify[%]
:[font = text; inactive; ]
These examples are artificial since I knew both the force field curves and the equipotential curves.  Now  the goal is clear:  Given a family of curves (such as force field curves), find the corresponding family of equipotential curves which as a result of physical reasoning, must be everywhere perpendicuular to the force field lines.
:[font = text; inactive; ]
Definition:  Let
				F(x,y,c) = 0
be a family of curves in the x-y plane.  A curve which intersects the curves of the family at right angles is called an orthogonal trajectory. of the given family.

Exercise:  Find the orthogonal trajectories to the family of parabolas y = c x^2

:[font = input; ]
ContourPlot[ y/x^2, {x, -1, 1}, {y, -1,1}, PlotPoints -> 40, ContourLevels -> 8]
:[font = text; inactive; ]
Now derive the differential equation for the family.
:[font = input; ]
D[ y[x] == c x^2, x]
:[font = input; ]
Reduce[%, y'[x]]
:[font = text; inactive; ]
The equation contains the parameter, which is not what we need.  We need the expression for hte differential equation to contain only the independent variable and the dependent variable.  So eliminate the constant c by using the equation for the original family: c = y/x^2.  The equation becomes 
					y' =  2 y/x
The equation for the family of orthogoanl trajectories becomes 
		y'  =  -x/2y
Notice that this is a separable differential equation.  This is typical.	The solution is almost trivial and certainly doesn't require the power of Mathematica.
		2y y' = - x
		2 y dy = - x dx
		y^2 = -x^2/2 + c
		x^2 + 2 y^2 = c
The orthogoanl trajectories are ellipses:
				
:[font = input; ]
ContourPlot[ x^2 + 2y^2, {x,-1,1}, {y,-1,1}] 
:[font = input; ]
ParametricPlot[ {{t, t^2}, {Sqrt[2] Cos[t], Sin[t]}},
  {t, 0, 2 Pi}, PlotRange -> {{0,2}, {0,2}}, AspectRatio -> Automatic]
:[font = text; inactive; ]
As a final exercise, an important set of field lines in practice are those of a electric dipole (like a bar magnet).  The field lines are given by F(x,y) = x/(x^2 - y^2) = c.  Find the equipotential lines which are the ortogonal trajectories.

^*)